(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     23956,        553]
NotebookOptionsPosition[     21790,        500]
NotebookOutlinePosition[     22144,        516]
CellTagsIndexPosition[     22101,        513]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Validation of the Boys Function", "Title",
 CellChangeTimes->{{3.709468418596403*^9, 
  3.7094684218732452`*^9}},ExpressionUUID->"ebdb1d77-0703-4005-8bc7-\
3b0982294458"],

Cell["\<\
SplitArbNumber will split a ball and associated radius in the format [1.234 + \
/- 3.4] and return only the first number. This will not
affect numbers not written in the Arb format\
\>", "Text",
 CellChangeTimes->{{3.716204951173174*^9, 
  3.716204956236785*^9}},ExpressionUUID->"698e7cdc-c70c-4a34-bf98-\
665f880a4fa3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SplitArbNumber", "[", "s_", "]"}], " ", ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "tmp", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"tmp", " ", "=", " ", 
      RowBox[{"StringReplace", "[", 
       RowBox[{"s", ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<[\>\"", "\[Rule]", "\"\<\>\""}], ",", " ", 
          RowBox[{"\"\<]\>\"", "\[Rule]", "\"\<\>\""}]}], "}"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"tmp", "=", 
      RowBox[{"StringSplit", "[", "tmp", "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tmp", "[", 
         RowBox[{"[", "1", "]"}], "]"}], " ", "==", " ", "\"\<+/-\>\""}], ",",
        " ", "\"\<0.0\>\"", ",", " ", 
       RowBox[{"tmp", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",ExpressionUUID->"488846e5-5ab6-437f-9e4d-8997d59459f6"],

Cell["\<\

The ParsePadNumber converts a string to a number by adding zeros after the \
decimal place, but before the \[OpenCurlyQuote]e\[CloseCurlyQuote].
It then replaces the \[OpenCurlyQuote]e\[CloseCurlyQuote] with \
\[OpenCurlyQuote]*10^\[CloseCurlyQuote] so that Mathematica will interpret it \
correctly (in ToExpression).

ParseNumber is similar, but doesn\[CloseCurlyQuote]t pad with zeros. This \
should be used to read reference values (rather than the integral input
parameters).\
\>", "Text",
 CellChangeTimes->{{3.7094674063635683`*^9, 3.7094675856869783`*^9}, {
   3.716203757613389*^9, 3.716203856450088*^9}, 3.716204546845344*^9, {
   3.7162046119614563`*^9, 3.716204614011373*^9}, 3.71620466759444*^9, {
   3.71620487995989*^9, 3.7162048961398163`*^9}, {3.7162049343303337`*^9, 
   3.716204981403268*^9}},ExpressionUUID->"6436d512-995e-470f-a052-\
3336d92700f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ParsePadNumber", "[", 
    RowBox[{"s_", ",", " ", "ndigits_"}], "]"}], " ", ":=", " ", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "a", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"a", " ", "=", " ", 
       RowBox[{"SplitArbNumber", "[", "s", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ToExpression", "[", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"StringContainsQ", "[", 
          RowBox[{"a", ",", " ", "\"\<.\>\""}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"StringReplace", "[", 
          RowBox[{"a", ",", 
           RowBox[{"\"\<e\>\"", "\[Rule]", 
            RowBox[{
             RowBox[{"StringRepeat", "[", 
              RowBox[{"\"\<0\>\"", ",", "ndigits"}], "]"}], "<>", 
             "\"\<*10^\>\""}]}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"StringReplace", "[", 
          RowBox[{"a", ",", 
           RowBox[{"\"\<e\>\"", "\[Rule]", 
            RowBox[{"\"\<.\>\"", "<>", 
             RowBox[{"StringRepeat", "[", 
              RowBox[{"\"\<0\>\"", ",", "ndigits"}], "]"}], "<>", 
             "\"\<*10^\>\""}]}]}], "]"}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.709465536007962*^9, 3.709465566498661*^9}, {
  3.709466001018497*^9, 3.709466002368306*^9}, {3.709466163467703*^9, 
  3.709466182772242*^9}, {3.709466330597824*^9, 3.7094664692872868`*^9}, {
  3.7094665034429607`*^9, 3.709466506500807*^9}, {3.709466779291071*^9, 
  3.709466779695282*^9}, {3.716204682284161*^9, 3.716204715486215*^9}, {
  3.716204846198967*^9, 
  3.716204858220688*^9}},ExpressionUUID->"800dc620-a9c9-4411-a6ce-\
8cc0f0923b82"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ParseNumber", "[", "s_", "]"}], " ", ":=", " ", 
   RowBox[{"ToExpression", "[", 
    RowBox[{"SplitArbNumber", "[", 
     RowBox[{"StringReplace", "[", 
      RowBox[{"s", ",", 
       RowBox[{"\"\<e\>\"", "\[Rule]", "\"\<*10^\>\""}]}], "]"}], "]"}], 
    "]"}]}], ";"}]], "Input",
 CellFrame->{{0, 0}, {0.5, 0}},
 CellChangeTimes->{{3.709465536007962*^9, 3.709465566498661*^9}, {
   3.709466001018497*^9, 3.709466002368306*^9}, {3.709466163467703*^9, 
   3.709466182772242*^9}, {3.709466330597824*^9, 3.7094664692872868`*^9}, {
   3.7094665034429607`*^9, 3.709466506500807*^9}, {3.709466779291071*^9, 
   3.709466818169997*^9}, 3.716204743073326*^9, {3.716204867942515*^9, 
   3.7162048755939217`*^9}},ExpressionUUID->"38795e19-dda2-4e44-bf9d-\
dc621259a5c4"],

Cell["\<\
Calculates the Boys function via the Incomplete Gamma function. Some \
processing is needed in case \[OpenCurlyQuote]t\[CloseCurlyQuote] is zero. \
The the result is rounded
to the desired number of digits\
\>", "Text",
 CellChangeTimes->{{3.709467619573038*^9, 3.709467640991873*^9}, {
  3.709468871962647*^9, 3.70946888141252*^9}, {3.709474202930978*^9, 
  3.7094742243521748`*^9}, {3.709476080505879*^9, 
  3.709476081809312*^9}},ExpressionUUID->"575f200f-5181-41e7-ac33-\
7804e5472586"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Boys", "[", 
   RowBox[{"m_", ",", "t_", ",", "ndigits_"}], "]"}], " ", ":=", 
  RowBox[{"N", "[", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"SameQ", "[", 
        RowBox[{"t", ",", " ", "0"}], "]"}], " ", "||", " ", 
       RowBox[{"SameQ", "[", 
        RowBox[{"t", ",", "0.0"}], "]"}]}], ",", 
      FractionBox["1", 
       RowBox[{
        RowBox[{"2", "*", "m"}], "+", "1"}]], ",", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", "*", 
         SuperscriptBox["t", 
          RowBox[{"m", "+", 
           FractionBox["1", "2"]}]]}]], " ", 
       RowBox[{"Gamma", "[", 
        RowBox[{
         RowBox[{"m", "+", 
          FractionBox["1", "2"]}], ",", " ", "0", ",", " ", "t"}], "]"}]}]}], 
     "]"}], ",", " ", "ndigits"}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0.5, 0}},
 CellChangeTimes->{{3.706392423334876*^9, 3.7063924790322247`*^9}, {
   3.7063925207608223`*^9, 3.706392555328702*^9}, {3.706392891407777*^9, 
   3.7063928965433607`*^9}, {3.706392992771782*^9, 3.706393003558852*^9}, {
   3.706393049306024*^9, 3.706393087770496*^9}, {3.706462119995701*^9, 
   3.7064621207156076`*^9}, {3.707040714281932*^9, 3.707040760579974*^9}, {
   3.707058422538856*^9, 3.7070584603834877`*^9}, {3.7070589705464077`*^9, 
   3.707058983505908*^9}, {3.707059110497162*^9, 3.707059125885373*^9}, {
   3.707067860338624*^9, 3.707067868349718*^9}, {3.7070683355408163`*^9, 
   3.7070683391816177`*^9}, {3.707068545551991*^9, 3.707068545775732*^9}, {
   3.707068885029584*^9, 3.707068905728286*^9}, {3.707068967919146*^9, 
   3.7070689782679367`*^9}, {3.7070814207307587`*^9, 
   3.7070814403146877`*^9}, {3.7070816220315228`*^9, 3.707081626358405*^9}, {
   3.707081743449644*^9, 3.707081776434688*^9}, {3.707082238564066*^9, 
   3.707082242614102*^9}, {3.707134825153985*^9, 3.707134831004768*^9}, {
   3.7071408751302633`*^9, 3.707140876300024*^9}, {3.709464770139367*^9, 
   3.709464797362501*^9}, {3.709464831160187*^9, 3.7094648728284082`*^9}, {
   3.709464981369882*^9, 3.709465007827533*^9}, {3.709465055978118*^9, 
   3.709465061197295*^9}, {3.709467395520336*^9, 3.70946739605846*^9}, {
   3.709468864808573*^9, 3.709468887083336*^9}, {3.709469475008555*^9, 
   3.7094694758757877`*^9}, {3.709469624363196*^9, 3.709469646096681*^9}, {
   3.709469677687784*^9, 3.709469777316968*^9}, {3.709474042373878*^9, 
   3.7094740513267727`*^9}, {3.7094742653921223`*^9, 3.709474275247583*^9}, {
   3.70947476093174*^9, 3.709474773305004*^9}, {3.709474840716569*^9, 
   3.709474842784936*^9}, {3.70947494232578*^9, 3.70947496747969*^9}, 
   3.709476084959878*^9, {3.709476145576479*^9, 
   3.709476146115086*^9}},ExpressionUUID->"c94f2ed4-4f9f-4f37-a3e8-\
031722223af0"],

Cell["\<\
Calculates a value for the Boys function then compares the computed value \
with the value in the file.

The input is expected to be a list {m, t, value}.
The output is {m, t, value, computed value, test result}.\
\>", "Text",
 CellChangeTimes->{{3.709467707098076*^9, 3.709467778646809*^9}, {
  3.709468783629136*^9, 3.709468792987637*^9}, {3.70946893631394*^9, 
  3.709468941397335*^9}, {3.709476094274585*^9, 3.7094760953094263`*^9}, {
  3.709476155250841*^9, 
  3.709476155834422*^9}},ExpressionUUID->"c351e459-f62c-46cc-a5b7-\
4aefe39023c8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BoysCompare", "[", 
   RowBox[{"vals_", ",", " ", "ndigits_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"refval", ",", "\[IndentingNewLine]", 
      RowBox[{"m", " ", "=", " ", 
       RowBox[{"vals", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"t", " ", "=", " ", 
       RowBox[{"vals", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "\[IndentingNewLine]", "}"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"refval", " ", "=", " ", 
      RowBox[{"Boys", "[", 
       RowBox[{"m", ",", " ", "t", ",", " ", "ndigits"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"m", ",", " ", "t", ",", " ", 
       RowBox[{"vals", "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", " ", "refval", ",", " ", 
       RowBox[{"SameQ", "[", 
        RowBox[{
         RowBox[{"vals", "[", 
          RowBox[{"[", "3", "]"}], "]"}], ",", "refval"}], "]"}]}], "}"}]}]}],
    "\[IndentingNewLine]", "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0.5, 0}},
 CellChangeTimes->{{3.707057226099612*^9, 3.707057234407737*^9}, {
   3.7070578473510017`*^9, 3.70705797569246*^9}, {3.7070580207358227`*^9, 
   3.7070580259553623`*^9}, {3.7070580767619*^9, 3.707058102728017*^9}, {
   3.707058158121513*^9, 3.707058177649152*^9}, {3.7070582155411863`*^9, 
   3.7070582273293657`*^9}, {3.7070589168230743`*^9, 3.707058942286147*^9}, {
   3.707059007311007*^9, 3.707059107300336*^9}, {3.707059152210926*^9, 
   3.707059155811098*^9}, {3.707063742501967*^9, 3.7070637714385023`*^9}, {
   3.707063855407247*^9, 3.7070638586909857`*^9}, {3.7070641816103897`*^9, 
   3.707064218689292*^9}, {3.707064313998538*^9, 3.707064322908375*^9}, {
   3.707064675753182*^9, 3.707064767999777*^9}, {3.707064868847015*^9, 
   3.7070648728952*^9}, 3.707064979636057*^9, {3.707065321363016*^9, 
   3.7070653245576878`*^9}, {3.707065381619588*^9, 3.707065386612608*^9}, {
   3.707065421397324*^9, 3.7070655147728653`*^9}, {3.7070656501321087`*^9, 
   3.7070657076853456`*^9}, {3.707067125222728*^9, 3.70706713260217*^9}, {
   3.7070683458419123`*^9, 3.707068415546089*^9}, {3.7070688155953693`*^9, 
   3.707068846147023*^9}, {3.70706899033001*^9, 3.707068996088241*^9}, {
   3.707078409733212*^9, 3.707078411187949*^9}, {3.707078446397641*^9, 
   3.707078452437827*^9}, {3.707079045082144*^9, 3.707079085802887*^9}, {
   3.707079167016048*^9, 3.707079168344212*^9}, {3.7070792454978456`*^9, 
   3.707079258184004*^9}, {3.7070794459448137`*^9, 3.707079453136479*^9}, {
   3.7071347028450117`*^9, 3.70713470801855*^9}, {3.707134765710267*^9, 
   3.707134778488614*^9}, {3.70713488437568*^9, 3.707134884599016*^9}, {
   3.707134924561316*^9, 3.707134953629632*^9}, {3.707135599741646*^9, 
   3.7071356001013308`*^9}, 3.707135640332108*^9, {3.709464922059537*^9, 
   3.709464923183413*^9}, {3.7094649682291307`*^9, 3.709464969263234*^9}, {
   3.7094650150285597`*^9, 3.709465038156458*^9}, {3.7094651502988777`*^9, 
   3.7094651516915216`*^9}, {3.709465457201894*^9, 3.7094654919798107`*^9}, {
   3.7094656602359467`*^9, 3.709465662303801*^9}, {3.709465868583123*^9, 
   3.709465874523543*^9}, {3.709466548982795*^9, 3.70946655100659*^9}, {
   3.709468799333931*^9, 3.709468805273114*^9}, {3.7094689046341248`*^9, 
   3.709468910033374*^9}, {3.7094761010256567`*^9, 3.7094761021950083`*^9}, {
   3.709476159794874*^9, 
   3.709476162854232*^9}},ExpressionUUID->"5e19414c-edf0-47b6-9d4d-\
bf64fca50bec"],

Cell["\<\
Runs the BoysCompare function over a list, returning only the failed tests.\
\>", "Text",
 CellChangeTimes->{{3.709467794306785*^9, 3.709467827336347*^9}, {
  3.709468755908865*^9, 3.7094687695875473`*^9}, {3.709468836817688*^9, 
  3.709468843388753*^9}, {3.709468899637395*^9, 3.70946892726726*^9}, {
  3.70947428924121*^9, 3.709474294056424*^9}, {3.70947616982922*^9, 
  3.709476170593526*^9}},ExpressionUUID->"23e3834f-c0b9-4fb7-8db9-\
c15eae899532"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TestList", "[", 
   RowBox[{"lst_", ",", " ", "ndigits_"}], "]"}], " ", ":=", " ", 
  RowBox[{"Module", " ", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rlist", " ", "=", " ", 
      RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Do", "[", 
      RowBox[{
       RowBox[{"AppendTo", "[", 
        RowBox[{"rlist", ",", " ", 
         RowBox[{"BoysCompare", "[", 
          RowBox[{
           RowBox[{"lst", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", "ndigits"}], "]"}]}], "]"}], 
       ",", " ", 
       RowBox[{"{", 
        RowBox[{"i", ",", " ", "1", ",", " ", 
         RowBox[{"Length", "[", "lst", "]"}]}], "}"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Select", "[", 
      RowBox[{"rlist", ",", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "5", "]"}], "]"}], " ", "\[Equal]", " ", "False"}], 
        " ", "&"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellFrame->{{0, 0}, {2, 0}},
 CellChangeTimes->{{3.707134999772694*^9, 3.7071350671646748`*^9}, {
  3.707135165716508*^9, 3.707135248336823*^9}, {3.707135326636896*^9, 
  3.707135470280178*^9}, {3.707135555057713*^9, 3.707135555505869*^9}, {
  3.70713565135844*^9, 3.707135651805645*^9}, {3.7094648159490128`*^9, 
  3.7094648163539143`*^9}, {3.7094650824831448`*^9, 3.70946511870726*^9}, {
  3.709465215412278*^9, 3.709465219866365*^9}, {3.709465252807519*^9, 
  3.709465253345285*^9}, {3.709465610330284*^9, 3.7094656166748037`*^9}, {
  3.709465927445051*^9, 3.7094659353182707`*^9}, {3.709466597851972*^9, 
  3.709466606671365*^9}, {3.709466927791545*^9, 3.709466960234941*^9}, {
  3.7094688098636303`*^9, 3.709468830653277*^9}, {3.7094743138569527`*^9, 
  3.709474315072172*^9}, {3.709476167356882*^9, 3.7094761753653517`*^9}, {
  3.716205524201804*^9, 
  3.716205524721262*^9}},ExpressionUUID->"2043c984-55cf-4687-bb47-\
13e37ecae92e"],

Cell["\<\
The file to validate. This should be in the parent directory of this notebook\
\
\>", "Text",
 CellChangeTimes->{{3.70946797174137*^9, 
  3.709468006120043*^9}},ExpressionUUID->"a13f1994-1cbc-4219-a117-\
db7899841c19"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"filename", " ", "=", " ", "\"\<boys_large_range.dat\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"testDir", " ", "=", " ", 
   RowBox[{"ParentDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"file", " ", "=", " ", 
  RowBox[{"FileNameJoin", "[", 
   RowBox[{"{", 
    RowBox[{"testDir", ",", " ", "filename"}], "}"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.707072935383239*^9, 3.707072942333709*^9}, {
  3.707140862441813*^9, 3.707140866399519*^9}, {3.7071522593247137`*^9, 
  3.707152259466902*^9}, {3.707152449065337*^9, 3.707152449202434*^9}, {
  3.707152987643042*^9, 3.70715299086803*^9}, {3.709461944510097*^9, 
  3.709461949773904*^9}, {3.70946465372624*^9, 3.70946465403813*^9}, {
  3.7094669675701733`*^9, 3.709466981160389*^9}, {3.709467253498301*^9, 
  3.7094672555679703`*^9}, {3.709467325994006*^9, 3.70946732617258*^9}, {
  3.709467976646607*^9, 3.7094680349208937`*^9}, {3.709468491805987*^9, 
  3.7094684923434277`*^9}, {3.709468620999476*^9, 3.7094686228877897`*^9}, {
  3.709468673559575*^9, 3.7094686789127493`*^9}, {3.716205625750473*^9, 
  3.7162056269257307`*^9}},ExpressionUUID->"40e83825-baf8-46a6-a0e2-\
90bd58d4713c"],

Cell["\<\
Import the data from the file as strings, removing empty lines and lines \
starting with \[OpenCurlyQuote]#\[CloseCurlyQuote].
Then grab the number of digits (from the first line), and parse the remaining \
data into a list of lists\
\>", "Text",
 CellChangeTimes->{{3.709468047700906*^9, 
  3.7094680958496304`*^9}},ExpressionUUID->"99f3ec31-5c16-42e2-b5fa-\
5fe436462e3c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"bdata", " ", "=", " ", 
   RowBox[{"Import", "[", 
    RowBox[{"file", ",", " ", 
     RowBox[{"\"\<Numeric\>\"", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bdata", " ", "=", " ", 
   RowBox[{"Select", "[", 
    RowBox[{"bdata", ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "#", "]"}], ">", "0"}], " ", "&&", 
       RowBox[{"Not", "[", 
        RowBox[{"StringStartsQ", "[", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", " ", "\"\<#\>\""}], "]"}], 
        "]"}]}], " ", "&"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fileDigits", " ", "=", " ", 
   RowBox[{"ToExpression", "[", 
    RowBox[{
     RowBox[{"bdata", "[", 
      RowBox[{"[", "1", "]"}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bdata", " ", "=", " ", 
   RowBox[{"Delete", "[", 
    RowBox[{"bdata", ",", " ", "1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bdata", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ToExpression", "[", 
        RowBox[{
         RowBox[{"bdata", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", " ", 
       RowBox[{"ParsePadNumber", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"bdata", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], ",", " ", "fileDigits"}], "]"}], 
       ",", " ", 
       RowBox[{"ParseNumber", "[", 
        RowBox[{
         RowBox[{"bdata", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "3", "]"}], "]"}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "1", ",", " ", 
       RowBox[{"Length", "[", "bdata", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.709462693188486*^9, 3.709462721341003*^9}, 
   3.709462777548061*^9, {3.7094628574674892`*^9, 3.709462924065778*^9}, {
   3.7094629897667713`*^9, 3.7094632991844387`*^9}, {3.709463339191839*^9, 
   3.709463370914159*^9}, {3.7094635468189793`*^9, 3.709463632948333*^9}, 
   3.70946388926826*^9, {3.7094639397578793`*^9, 3.709463940971799*^9}, {
   3.709463995197721*^9, 3.709464092306281*^9}, {3.709464183791666*^9, 
   3.7094644006004543`*^9}, 3.709464430796686*^9, {3.709464740484138*^9, 
   3.70946474444242*^9}, {3.709465569561042*^9, 3.70946559286938*^9}, {
   3.709466217693492*^9, 3.709466225117858*^9}, 3.709466632232119*^9, {
   3.709466830140504*^9, 3.7094668357219048`*^9}, {3.7162051342323313`*^9, 
   3.716205134302423*^9}},ExpressionUUID->"7fb2a781-a01c-4f81-a9b4-\
fafc0b3f8ac2"],

Cell[BoxData[
 RowBox[{"Length", "[", "bdata", "]"}]], "Input",
 CellChangeTimes->{{3.709467263006444*^9, 
  3.7094672653779163`*^9}},ExpressionUUID->"a7419c27-4604-4991-8cff-\
03bbf777d84c"],

Cell["\<\
Run the test. If the CompareList returns an empty list, that means all has \
succeeded. If the list does not have any entries, then
it contains the information for the failed tests

Test with the incomplete gamma\
\>", "Text",
 CellChangeTimes->{{3.709468105930695*^9, 3.709468123839519*^9}, {
  3.709468154214293*^9, 3.709468166544252*^9}, {3.7094683594585238`*^9, 
  3.709468381238722*^9}, {3.7094689671822653`*^9, 3.7094689746071*^9}, {
  3.709469051106928*^9, 3.7094690557871943`*^9}, {3.7094741847965803`*^9, 
  3.70947419334518*^9}, {3.716205186733032*^9, 3.716205194800634*^9}, {
  3.716205513284326*^9, 
  3.716205516474951*^9}},ExpressionUUID->"1a15df08-19da-44a5-88fe-\
7f84bf22ce9f"],

Cell[BoxData[
 RowBox[{"TestList", "[", 
  RowBox[{"bdata", ",", " ", "fileDigits"}], "]"}]], "Input",
 CellChangeTimes->{{3.707135443608491*^9, 3.7071354475950327`*^9}, {
   3.709464914228891*^9, 3.7094649182321157`*^9}, {3.709466724885898*^9, 
   3.709466725740499*^9}, {3.709468129690316*^9, 3.709468148994829*^9}, {
   3.709468198630547*^9, 3.7094682023187943`*^9}, {3.709468257670992*^9, 
   3.7094682632935543`*^9}, {3.7094682983958263`*^9, 
   3.7094682992938843`*^9}, {3.709468347670507*^9, 3.709468352258995*^9}, {
   3.709468997017447*^9, 3.7094689977822533`*^9}, 3.709476180043968*^9, {
   3.716205520263782*^9, 
   3.7162055207950583`*^9}},ExpressionUUID->"f3cc5825-6c0d-488f-92bd-\
4008685b3f0b"]
}, Open  ]]
},
WindowSize->{1680, 955},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.1 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 18, \
2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 176, 3, 92, "Title", "ExpressionUUID" -> \
"ebdb1d77-0703-4005-8bc7-3b0982294458"],
Cell[759, 27, 330, 7, 49, "Text", "ExpressionUUID" -> \
"698e7cdc-c70c-4a34-bf98-665f880a4fa3"],
Cell[1092, 36, 1033, 26, 138, "Input", "ExpressionUUID" -> \
"488846e5-5ab6-437f-9e4d-8997d59459f6"],
Cell[2128, 64, 880, 17, 125, "Text", "ExpressionUUID" -> \
"6436d512-995e-470f-a052-3336d92700f3"],
Cell[3011, 83, 1794, 40, 180, "Input", "ExpressionUUID" -> \
"800dc620-a9c9-4411-a6ce-8cc0f0923b82"],
Cell[4808, 125, 808, 17, 41, "Input", "ExpressionUUID" -> \
"38795e19-dda2-4e44-bf9d-dc621259a5c4"],
Cell[5619, 144, 500, 10, 49, "Text", "ExpressionUUID" -> \
"575f200f-5181-41e7-ac33-7804e5472586"],
Cell[6122, 156, 2760, 54, 67, "Input", "ExpressionUUID" -> \
"c94f2ed4-4f9f-4f37-a3e8-031722223af0"],
Cell[8885, 212, 556, 12, 87, "Text", "ExpressionUUID" -> \
"c351e459-f62c-46cc-a5b7-4aefe39023c8"],
Cell[9444, 226, 3552, 63, 189, "Input", "ExpressionUUID" -> \
"5e19414c-edf0-47b6-9d4d-bf64fca50bec"],
Cell[12999, 291, 463, 8, 30, "Text", "ExpressionUUID" -> \
"23e3834f-c0b9-4fb7-8db9-c15eae899532"],
Cell[13465, 301, 1995, 44, 127, "Input", "ExpressionUUID" -> \
"2043c984-55cf-4687-bb47-13e37ecae92e"],
Cell[15463, 347, 228, 6, 30, "Text", "ExpressionUUID" -> \
"a13f1994-1cbc-4219-a117-db7899841c19"],
Cell[15694, 355, 1265, 24, 75, "Input", "ExpressionUUID" -> \
"40e83825-baf8-46a6-a0e2-90bd58d4713c"],
Cell[16962, 381, 384, 8, 49, "Text", "ExpressionUUID" -> \
"99f3ec31-5c16-42e2-b5fa-5fe436462e3c"],
Cell[17349, 391, 2812, 70, 117, "Input", "ExpressionUUID" -> \
"7fb2a781-a01c-4f81-a9b4-fafc0b3f8ac2"],
Cell[20164, 463, 191, 4, 32, "Input", "ExpressionUUID" -> \
"a7419c27-4604-4991-8cff-03bbf777d84c"],
Cell[20358, 469, 704, 14, 87, "Text", "ExpressionUUID" -> \
"1a15df08-19da-44a5-88fe-7f84bf22ce9f"],
Cell[21065, 485, 709, 12, 32, "Input", "ExpressionUUID" -> \
"f3cc5825-6c0d-488f-92bd-4008685b3f0b"]
}, Open  ]]
}
]
*)

